# file for tracking known "styles" of wine - for classification purposes
# important to note: this file is used to convert "style" into "grape", "region" or "sweetness"

# import re
# from collections import namedtuple
# from ..pygrape import grapes, 


# WineStyle = namedtuple("WineStyle", ["grapes", "regions", "sweetness", "color"])


# mapping = {
#     "vin santo": {
#         regex: r"vin santo",
#         styles: [
#             WineStyle(grapes=["Malvasia"], regions=[regions.TUSCANY]),
#             WineStyle(grapes=["Trebbiano"], regions=[regions.TUSCANY]),
#         ]
#     },
#     "occhio di pernice": {
#         regex: r"occhio di pernice",
#         styles: [
#             WineStyle(grapes=["Sangiovese"], regions=[regions.TUSCANY]),
#         ]
#     },
#     "manzanilla": {
#         regex: r"(?:fino|manzanilla|fino sherry|sherry fino)",
#         styles: [
#             WineStyle(grapes=["Palomino"], regions=[regions.ANDALUSIA]),
#             WineStyle(grapes=["Pedro Ximenez"], regions=[regions.ANDALUSIA]),
#             WineStyle(grapes=["Moscatel de Grano Menudo"], regions=[regions.ANDALUSIA]),
#             WineStyle(grapes=["Moscatel de Alejandría"], regions=[regions.ANDALUSIA]),
#         ]
#     },
# }


import json
import re
from collections import namedtuple
from unidecode import unidecode

from thefuzz import fuzz, process

from .data import grapes as data
from ..pyregion import regions

grape_to_object = {}


def format_name(name: str) -> str:
    return name.lower().replace("i̇", "i").title()


for o in data:
    name = format_name(o["name"])
    grape_to_object[name] = {**o, "name": name}

# named tuple


Grape = namedtuple("Grape", ["name", "synonyms", "description", "color", "numeric"])


# create a generator of grapes
class ExistingGrapes:
    __slots__ = ["grapes", "_synonym_to_name"]

    def __init__(self) -> None:
        self.grapes = []
        self._synonym_to_name = {}
        for name in grape_to_object:
            grape = Grape(
                name=name,
                synonyms=grape_to_object[name].get("synonyms", []),
                description=grape_to_object[name].get("description", None),
                color=grape_to_object[name].get("color", None),
                numeric=list(grape_to_object.keys()).index(name),
            )

            # stylize_attr_name = lambda name: re.sub(r"\s", "_", name.upper())
            # setattr(self, stylize_attr_name(name), grape)


            self.grapes.append(grape)
            self._synonym_to_name[name] = name
            self._synonym_to_name[unidecode(name)] = name
            for synonym in grape.synonyms:
                if re.search(r"×", synonym):
                    continue
                # if re.search(r"\d", synonym) or re.search(r"×", synonym):
                    # continue
                self._synonym_to_name[synonym] = name
                self._synonym_to_name[unidecode(synonym)] = name

    def __iter__(self) -> Grape:
        yield from self.grapes

    def __getitem__(self, index: int) -> Grape:
        return self.grapes[index]

    def __len__(self) -> int:
        return len(self.grapes)

    def __repr__(self) -> str:
        return f"ExistingGrapes({len(self.grapes)})"

    def __str__(self) -> str:
        return f"ExistingGrapes({len(self.grapes)})"

    def get(self, **kwargs) -> Grape:
        for grape in self.grapes:
            if all(getattr(grape, k) == v for k, v in kwargs.items()):
                return grape
        return None

    def search_fuzzy(self, grape: str, threshold: int = 82) -> Grape:
        name = unidecode(grape)

        name, distance = process.extractOne(
            grape, 
            self._synonym_to_name.keys(), 
            scorer=fuzz.QRatio
        )
        if distance > threshold:
            return self.get(name=self._synonym_to_name[name])
        else:
            return None

    def extract_region(self, grape: str, threshold: int = 82) -> tuple:
        # first we check for included region names i.e "Bordeaux", "d'Asti", "de Bourgogne"
        region = regions.search_fuzzy(grape, threshold=95)

        if region is not None and grape not in ['Rosette']:
            return None, region
        
        # id contains d'Asti, de Bourgogne, etc.
        ptrn = r"(.+)\b(?:d'|de\s|della\s)(\w+)"
        match = re.search(ptrn, grape)

        if not match:
            grape, region = grape, None
        else:
            grape, region = match.groups()
            region = regions.search_fuzzy(region, threshold=threshold)

        return grape, region
        

    def search(self, grape: str, fuzzy: bool = False, threshold: int = 82, with_region = False) -> Grape:
        name = unidecode(grape)

        if not with_region:
            if fuzzy:
                grape = self.search_fuzzy(name, threshold=threshold)
            else:
                grape = self.get(name=self._synonym_to_name.get(name))

        name, region = self.extract_region(name, threshold=threshold)

        if not name:
            return None, region

        if fuzzy:
            grape = self.search_fuzzy(name, threshold=threshold)
        else:
            grape = self.get(name=self._synonym_to_name.get(name))

        return grape, region


grapes = ExistingGrapes()



# # from utils import *
# import html
# import unicodedata

# from unidecode import unidecode

# from . import regex as re_
# from .utils import *


# def normalize(phrase):
#     phrase = unicodedata.normalize("NFD", phrase)
#     phrase = unidecode(phrase)
#     phrase = phrase.lower()
#     phrase = re.sub(r"\([^)]*\)", "", phrase)
#     phrase = re.sub(r"\(|\)", "", phrase)

#     for vulgar_fraction, fraction_str in vf.dictionary.items():
#         phrase = re.sub(vulgar_fraction, " " + fraction_str + " ", phrase)

#     phrase = phrase.replace("–", "-")
#     phrase = phrase.replace("⁄", "/")
#     phrase = re.sub(r"half ?(?:and|-) ?half", "half-and-half", phrase)
#     phrase = re.sub(r"\.\.+", "", phrase)
#     phrase = re.sub(r" *\. *(?![0-9])", ". ", phrase)
#     phrase = re.sub(r"(?<=[0-9]) *\. *(?=[0-9])", ".", phrase)
#     phrase = re.sub(r" '", "'", phrase)
#     phrase = re.sub(r"(,[^,]+)?< ?a href.*", "", phrase)
#     phrase = re.sub(r""" *<(?:"[^"]*"['"]*|'[^']*'['"]*|[^'">])+> *""", "", phrase)
#     phrase = re.sub(r"(?<=[a-z])/[a-z]+", "", phrase)
#     phrase = re.sub(r"\b(?:5|five)[- ]?spice", "fivespice", phrase)
#     phrase = re.sub(r".*: ?", "", phrase)
#     phrase = re.sub(r"\s+", " ", phrase)
#     phrase = phrase.strip()
#     return phrase


# def read_phrase(phrase):
#     if not P_filter(str(phrase)):
#         return None

#     phrase = html.unescape(phrase)
#     phrase = normalize(phrase)
#     phrase = P_duplicates(phrase)

#     phrase = P_multi_misc_fix(phrase)
#     phrase = P_multi_misc_fix(phrase)
#     phrase = P_missing_multiplier_symbol_fix(phrase)
#     phrase = P_quantity_dash_unit_fix(phrase)
#     phrase = P_juice_zest_fix(phrase)

#     values = re.search(re_.INGREDIENT, phrase).groupdict()

#     values["unit"] = None
#     if values["quantity"]:
#         values["quantity"], values["unit"] = re.search(
#             rf"(?P<quantity>{re_.Q})? ?(?P<unit>.*)?", values["quantity"]
#         ).groups()
#         values["quantity"] = Q_to_number(values["quantity"])

#     values["unit"] = U_unify(values["unit"])
#     values["quantity"], values["unit"] = Q_U_unify(values["quantity"], values["unit"])

#     values["size"] = S_unify(values["size"])

#     if values["ingredient"] != values["ingredient"] or not values["ingredient"]:
#         return None

#     values["ingredient"] = I_to_singular(values["ingredient"])
#     values["simple"] = I_label_protein(values["ingredient"])
#     values["simple"] = I_simplify(values["simple"])

#     if values["simple"] == "sugar":
#         values["quantity"], values["unit"] = Q_U_sugar(
#             values["quantity"], values["unit"]
#         )

#     values["simple"] = re.sub(r"\bnan\b", "naan", values["simple"])

#     filtered = {
#         c: values[c]
#         for c in ["quantity", "unit", "size", "color", "ingredient", "simple"]
#     }
#     filtered["simple"] = values["simple"]
#     return filtered



import re

dictionary = {
    "salad dressing": [r"salad dressing$"],
    "vinaigrette": [r"vinaigrette"],
    "wine vinegar": [r"wine vinegar"],
    "cider vinegar": [r"c[iy]der vinegar"],
    "balsamic vinegar": [r"balsamic vinegar"],
    "rice vinegar": [r"rice vinegar$"],
    "vinegar": [r"vinegar$"],
    "rice": [
        r"\brice$",
        r"\bgrain$",
        r"\barborio$",
        r"\bbasmati$",
        r"\bbaldo$",
        r"carnarolli$",
        r"maratelli$",
        r"vialone nano",
    ],
    "couscous": [r"couscous$"],
    "oil": [r"\boil$", r"oil spray"],
    "gravy": [r"\bgravy$"],
    "bone": [r"\bbones?$"],
    "jalapeno": [r"^jalapeno(?:$| pepper$)"],
    "ghee": [r"ghee"],
    "nut butter": [r"(?:nut|cashew|almond).*butter$"],
    "butter": [r"butter margarine", r"margarine", r"butter$"],
    "water": [
        r"(?:cold |hot |warm |\bice |soda |tap |seltzer |cool |pasta |salt |lukewarm |^)water$"
    ],
    "egg": [r"(?<!chocolate )\beggs?$"],
    "tomato": [r" tomato$"],
    "potato": [r" potato$"],
    "masala": [r"masala"],
    "dark chocolate": [r"dark chocolate"],
    "white chocolate": [r"white chocolate"],
    "chocolate": [r"chocolate baking square", r"chocolate$", r"chocolate square"],
    "wonton wrapper": [r"spring wrapper"],
    # ALCOHOL
    "irish cream": [r"irish cream", r"bailey's"],
    "beer": [r"\bbeer$", r"\bale$", r"\bstout$"],
    "whiskey": [r"whiske?y$", r"scotch$"],
    "vodka": [r"\bvodka$"],
    "cider": [r"c[iy]der$"],
    "citrus liqueur": [r"limoncello", r"orange liqueur", r"margarita mix"],
    "fruit liqueur": [r"amaretto", r"curacao"],
    "liqueur": [
        r"rumchata",
        r"\brum$",
        r"liqueur$",
        r"liquor$",
        r"creme de cacao",
        r"frangelico",
        r"rum$",
        r"amarula cream liqueur",
        r"ouzo",
        r"kirsch",
        r"bourbon$",
        r"brandy$",
        r"^gin$",
        r"kahlua",
        r"grand marnier",
        r"cognac",
        r"triple sec",
        r"vodka",
        r"tequila",
        r"brandy",
        r"bitters?$",
    ],
    "grain mustard": [r"grainy mustard$"],
    "dijon mustard": [r"dijon mustard$"],
    "mustard": [r"mustard$"],
    "olive": [r"\bolive$"],
    "fortified wine": [
        r"marsala(?: wine)?$",
        r"madeira wine$",
        r"port wine$",
        r"mistell?a wine",
        r"\bport$",
        r"vermouth",
        r"sherry wine$",
        r"sherry$",
    ],
    "rice wine": [
        r"shaoxing wine$",
        r"rice wine$",
        r"cooking wine",
        r"^sake$",
        r"chinese wine$",
    ],
    "wine": [r"\bwine"],
    "spicy pepper": [
        r"chipotle chile",
        r"chill?[iey](?: pepper)?$",
        r"hot pepper$",
        r"serrano(?: pepper)?$",
        r"poblano(?: pepper)?$",
        r"scotch bonnet(?: pepper)?$",
        r"habanero(?: pepper)?$",
        r"chipotle(?: pepper)?$",
        r"pepperoncini(?: pepper)?$",
        r"banana pepper$",
        r"anaheim chili",
        r"pimi?ento(?: pepper)?$",
        r"\bchile$",
        r"\bchilly$",
        r"\bchili$",
    ],
    "bell pepper": [r"green pepper", r"yellow pepper", r"capsicum", r"bell pepper$"],
    "scallion": [r"green onion$", r"spring onion$", r"scallion$", r"\bleek$"],
    "pearl onion": [
        r"pearl onion$",
        r"baby onion$",
        r"pickling onion$",
        r"cocktail onion$",
    ],
    "onion": [r"\bonion$"],
    "food coloring": [r"coloring$"],
    "sugar": [r"sugar substitute", r"jaggery", r"sweetener", r"splenda", r"\bsugar$"],
    "corn": [
        r"\bmaize$",
        r"ear corn",
        r"mexican corn",
        r"sweetcorn",
        r"mexicorn",
        r"corn cob",
        r"white corn",
        r"kernel",
    ],
    "egg white": [r"egg beater substitute"],
    "avocado": [r"avocado(?: pear)?$", r"alligator pear$"],
    "yogurt": [r"yogh?o?urt"],
    "foil": [r"foil$"],
    "bulgur": [r"bulgh?[au]r wheat", r"bulgh?[au]r$"],
    "pineapple": [
        r"pineapple rings?",
        r"pineapple$",
        r"pineapple tidbits?",
        r"pineapple chunks?",
        r"ananas$",
    ],
    "pepper": [r"pepper powder$"],
    "coffee": [r"black cofee$", r"espresso", r"coffee$"],
    "coffee powder": [r"espresso powder", r"coffee granule"],
    "miso": [r"\bmiso$"],
    "celery": [r"celery(?: sticks?| roots?)?$"],
    "arugula": [r"arug[ua]la", r"roquette$", r"rocket", r"rucola"],
    "syrup": [r"syrup$", r"nectar$", r"sirup$"],
    "shortening": [r"shortening", r"crisco"],
    "cracker": [r"cracker$", r"matzo meal", r"matzo"],
    "molasses": [r"molasses"],
    "salsa": [r"salsa$", r"rotel tomato chilies", r"^rotel"],
    "garlic powder": [r"garlic granule"],
    "garlic head": [r"head garlic", r"bulb garlic"],
    "fat": [r"\bsuet$", r"\bgrease$", r"\bdripping$", r"\blard$", r"\bfat$"],
    "yeast": [r"yeast$"],
    "italian seasoning": [
        r"italian spice",
        r"italian herb",
        r"italian.*seasoning",
    ],
    "za'atar seasoning": [r"za'?atar"],
    "dressing": [r"dressing(?: mix)?"],
    "msg": [r"accent seasoning", r"msg$", r"monosodium glutamate"],
    "coconut cream": [r"cream coconut"],
    "coconut": [r"coconut$", r"coconut meat"],
    "mayonnaise": [r"miracle whip", r"mayo$", r"mayonnaise$"],
    "hominy": [r"hominy$"],
    "bisquick": [r"bisquick"],
    "lemon pepper": [r"lemon[- ]?pepper"],
    "bread roll": [
        r"^french$",
        r"^crescent$",
        r"^kaiser$",
        r"hoagie",
        r"crescent dinner",
        r"french baguette",
        r"baguette",
    ],
    "bok choy": [r"bok cho[iy]", r"pak cho[yi]"],
    "bouillon cube": [r"buillon cube", r"buillon granule", r"stock cube"],
    "tortilla": [r"tortilla$", r"egg wrap"],
    "salami": [r"salami$", r"pepperoni$"],
    "flower water": [r"flower water", r"rose water"],
    "sweet potato": [r"yam", r"sweet potato", r"kumara"],
    "pita bread": [r"pita bread"],
    "heavy cream": [
        r"double cream$",
        r"whipping cream",
        r"^cream$",
        r"half cream",
        r"nonfat cream",
        r"single cream",
    ],
    "bread": [r"bread$", r"ciabatta"],
    "cooking spray": [r"cooking spray"],
    "liquid smoke": [r"liquid smoke"],
    "milk": [r"\bmilk$"],
    "milk powder": [r"milk powder", r"powdered milk"],
    "tofu": [r"tofu$"],
    "pickle": [r"pickle$", r"gherkin", r"pickled cucumber$", r"cornichon$"],
    "skewer": [r"skewer$"],
    "broccoli": [r"broccoli$"],
    "eggplant": [r"aubergine"],
    "zucchini": [r"courgette", r"zucchinis?"],
    "honey": [r"honey$"],
    "saffron": [r"saffron"],
    "sweet sour mix": [r"^mix$"],
    "chili flake": [r"chili flake$", r"pepper flake$"],
    "mango chutney": [r"chutney$"],
    "tortilla chip": [r"tortilla chip", r"corn chip"],
    "all-purpose flour": [r"masa harina"],
    "whipped cream": [r"cool whip"],
    "breadcrumb": [r"breadcrumb$", r"bread crumb"],
    "pesto": [r"pesto"],
    "ketchup": [r"ketchup$", r"catsup", r"cetchup"],
    "oat": [r"\boat$"],
    "pistachio": [r"pistachio"],
    "soy milk": [r"soymilk"],
    "kiwi": [r"kiwi fruit", r"kiwi$", r"chineese gooseberry"],
    "asparagus": [r"asparagus spear"],
    "barley": [r"pearl barley"],
    "starch": [r"starch$", r"cornstarch", r"pectin"],
    "maraschino cherry": [r"glace cherry"],
    "phyllo pastry": [r"phyllo dough"],
    "cornmeal": [r"cornmeal", r"indian meal$"],
    "spinach": [r"spinach leaf"],
    "vanilla extract": [r"vanilla essence", r"^vanilla$"],
    "vanilla bean": [r"vanilla pod"],
    "raisin": [r"sultana"],
    "sour cream": [r"creme fraiche", r"sour(?:ed)? cream"],
    "pie crust": [r"pie shell", r"crust pie"],
    "vanilla ice cream": [r"ice cream"],
    "lettuce": [r"lettuce leaf", r"leaf lettuce"],
    "cream of tartar": [r"cream tartar", r"potassium bitartrate"],
    "beet": [r"beetroot"],
    "ice": [r"ice cube", r"\bice$"],
    "cocoa": [r"cocoa powder"],
    "cauliflower": [r"^cauliflower"],
    "lemongrass": [r"lemon ?grass"],
    "artichoke": [r"artichoke(?: hearts?)?$"],
    # ROOTS
    "jicama": [r"jicama"],
    "sunchoke": [r"sunchoke"],
    "ginger": [
        r"ginger ?(?:root|paste|powder)",
        r"root ginger",
    ],
    "turmeric": [r"turmeric powder", r"turmeric"],
    "wasabi": [r"wasabi paste", r"wasabi powder", r"wasabi"],
    "horseradish": [r"horseradish"],
    "root vegetable": [
        r"root vegetable",
        r"root veggie",
        r"root veg",
        r"daikon$",
        r"radish$",
        r"parsnip$",
        r"turnip$",
        r"rutabaga$",
    ],
    # HERBS
    "mint": [r"mint leaf", r"mint$"],
    "basil": [r"basil leaf", r"\bbasil$"],
    "cilantro": [r"cilantro$", r"coriander(?: cress)?$"],
    "dill": [r"dill weed", r"dill$"],
    "oregano": [r"oregano", r"marjoram"],
    "thyme": [r"thyme leaf", r"thyme leave", r"thyme$"],
    "parsley": [r"parsley$", r"parsley leaf", r"parsley flake"],
    "rosemary": [r"rosemary leaf", r"rosemary$"],
    "fenugreek": [
        r"fenugreek$",
        r"fenugreek leaf",
        r"methi$",
        r"methi leaf",
        r"greek clover",
    ],
    "sage": [r"\bsage leaf", r"\bsage$"],
    "tarragon": [r"tarragon leaf", r"tarragon$"],
    "chive": [r"\bchive$", r"\bchive stalk"],
    "bay leaf": [r"bay leaf", r"bay leave"],
    "chervil": [r"chervil$"],
    "lavender": [r"lavender$"],
    "savory": [r"savory$"],
    "watercress": [r"watercress$"],
    "sorrel": [r"sorrel$"],
    # LEGUMES
    "brussel sprout": [r"brussels? sprouts?"],
    "vanilla bean": [r"^vanilla beans?$"],
    "coffee bean": [r"\bcoffee beans?\b", r"espresso bean"],
    "sprout": [r"\bsprouts?\b"],
    "lentil": [r"\blentil(?:s?| bean)$"],
    "pea": [r"^snow$", r"\bpea(?:s?| bean)$"],
    "dal": [
        r"\bchann?a\b",
        r"\bur[ai]d\b",
        r"\btoor\b",
        r"\bdhal$",
        r"\bdal$",
        r"\bpulse$",
    ],
    "edamame": [r"\bsoy beans?$", r"\bedamame(?:s?| bean)$"],
    "chickpea": [r"\bchickpeas?$", r"\bbengal\b", r"\bgarbanzo\b"],
    "bean": [r"\brajma\b", r"\bbeans?$", r"bean kidney", r"\bcannellini(?:s?| bean)$"],
    # MUSHROOMS
    "morel mushroom": [r"\bmorels?\b"],
    "cremini mushroom": [
        r"button mushroom",
        r"cremini",
        r"baby port[oa]bell[oa]",
        r"chestnut.*mushroom",
        r"baby bella",
        r"brown.*mushroom",
        r"crimini",
    ],
    "chanterelle mushroom": [r"chante?relle", r"girolle", r"golden.*mushroom"],
    "black mushroom": [r"black.*mushroom"],
    "enoki mushroom": [r"enoki", r"beech", r"shimeji"],
    "oyster mushroom": [r"oyster", r"trumpet.*mushroom"],
    "shiitake mushroom": [r"shiitake", r"chinese.*mushroom", r"japanese.*mushroom"],
    "porcini mushroom": [r"porcini", r"bolet", r"king mushroom"],
    "champignon mushroom": [
        r"field mushroom",
        r"port[ao]bell[ao]",
        r"straw mushroom",
        r"large mushroom",
        r"champignon",
    ],
    "mushroom": [r"mushroom$", r"mushroom cap", r"mushroom stem"],
    # PASTA
    "pasta": [
        r"rigatoni",
        r"rotini",
        r"ziti",
        r"pasta shell",
        r"vermicelli",
        r"pasta shell",
        r"gnocchi",
        r"manicotti",
        r"noodle",
        r"noodles",
        r"spaghetti",
        r"penne",
        r"pappardelle",
        r"orecchiette",
        r"macaroni",
        r"linguine",
        r"farfalle",
        r"fusilli",
        r"fettuccine",
        r"capellini",
        r"lasagna",
        r"angel hair",
        r"dital[io]ni",
        r"paccheri",
        r"tort[ei]glioni",
        r"cavatelli",
        r"conchiglie",
        r"orzo",
        r"risoni",
        r"ravioli",
        r"tortell[io]ni",
        r" pasta$",
    ],
    # FLOUR
    "wheat flour": [
        r"whole[ -]?(?:meal|wheat) flour",
        # grain flours
        r"graham flour",
        r"teff flour",
        r"oat flour",
        r"buckwheat flour",
        r"quinoa flour",
        r"rye flour",
        r"spelt flour",
        r"sorghum flour",
        r"chickpea flour",
        r"gram flour",
        # white grain flours
        r"masa harina",
        r"amaranth flour",
        r"barley flour",
        r"rice flour",
        r"millet flour",
        r"corn flour",
        r"potato flour",
    ],
    "flour": [r" flour$"],
    # CHEESE
    "monterey jack cheese": [r"monterey jack"],
    "mexican cheese": [r"queso fresco", r"mexican cheese$"],
    "feta cheese": [r"\bfeta$"],
    "mozzarella cheese": [r"mozzarella", r"stracciatella$", r"stracciatella cheese"],
    "pecorino cheese": [r"pecorino"],
    "mascarpone cheese": [r"mascarpone"],
    "ricotta cheese": [r"ricotta"],
    "gruyere cheese": [r"gruyere(?: cheese)?"],
    "swiss cheese": [r"swiss cheese", r"emmenth?al(?:er)?"],
    "cottage cheese": [r"cottage cheese", r"cottage$", r"farmers? cheese"],
    "pepper jack cheese": [r"pepper ?jack"],
    "cream cheese": [r"cream cheese$", r"neufchatel"],
    "cheddar cheese": [
        r"cheddar cheese$",
        r"cheddar(?: cheese)?$",
        r"caerphilly(?: cheese)?",
    ],
    "brie cheese": [
        r"brie(?: cheese)?$",
        r"camembert(?: cheese)?$",
        r"goat'?s? cheese$",
    ],
    "parmesan cheese": [r"parmigiano", r"parmesan", r"grana? padano"],
    "paneer cheese": [r"pan(?:ee|i)r(?: cheese)?"],
    "halloumi cheese": [
        r"halloumi(?: cheese)?",
        r"hellim(?: cheese)?",
        r"hallumi(?: cheese)?",
        r"cypriot cheese",
    ],
    "blue cheese": [
        r"blue(?: cheese)?$",
        r"blue cheese crumble",
        r"gorgonzola(?: cheese)?",
        r"roquefort(?: cheese)?",
        r"stilton(?: cheese)?",
        r"danish blue(?: cheese)?",
        r"bleu(?: cheese)?",
    ],
    "cheese": [r"cheese$"],
    # STOCKS
    "chicken stock": [
        r"chicken stock",
        r"chicken broth",
        r"chicken bouillon",
        r"chicken granule",
    ],
    "vegetable stock": [
        r"(?:vegetable|veggie) stock",
        r"(?:vegetable|veggie) broth",
        r"(?:vegetable|veggie) bouillon",
        r"(?:vegetable|veggie) granule",
    ],
    "beef stock": [r"beef (?:stock|broth|bouillon|granule|juice|consomme|veloute)"],
    "fish stock": [
        r"(?:fish|seafood|crab|mussel) (?:stock|broth|bouillon|granule|juice|consomme|veloute)"
    ],
    "pork stock": [r"pork (?:stock|broth|bouillon|granule|juice|consomme|veloute)"],
    "stock": [r"(?:stock|broth|bouillon|granule|consomme|veloute)$"],
    # SAUCES
    "adobo sauce": [r"chipotle pepper adobo sauce"],
    "soy sauce": [r"ketjap manis", r"soya? sauce", r"tamari$", r"tamari sauce"],
    "tomato sauce": [r"tomato sauce$", r"tomato puree"],
    "fish sauce": [r"nam pla", r"fish sauce", r"seafood sauce"],
    "enchilada sauce": [r"enchilada sauce"],
    "hot sauce": [r"sriracha", r"adobo sauce", r"hot sauce"],
    "pepper sauce": [r"pepper.*sauce$"],
    "garlic paste": [r"garlic paste"],
    "chili paste": [
        r"chill?i?[iey].*paste",
        r"adobo.*(?:paste|sauce)",
        r"ranchero.*sauce",
    ],
    "curry paste": [r"curry.*paste"],
    "tomato paste": [r"tomato.*paste"],
    # SPICES
    "salt": [r"\bsalt(?:.*pepper)?$", r"\bsalt$", r"sea-salt$"],
    "garlic": [r"garlic$", r"garlic bulb", r"garlic clove"],
    "mustard powder": [r"mustard powder"],
    "coriander powder": [r"coriander powder"],
    "fivespice": [r"fivespice"],
    "spicy powder": [
        "cayenne",
        r"chill?[iey] powder",
        r"(?:chipotle|habanero|poblano|pepperoncino).*powder",
    ],
    "curry powder": [r"curry.*powder"],
    "cardamom": [r"cardamom powder", r"cardamom$"],
    "cumin": [
        r"cumin(?: powder)?$",
        r"jeera(?: powder)?$",
        r"nigella seed",
        r"caraway(?: seed)?$",
    ],
    "cinammon": [
        r"(?:cinammon|cassia)(?: powder| bark)?$",
    ],
    "peppercorn": [r"peppercorn$"],
    "sichuan pepper": [
        r"(?:whole)?sz?[ei]ch[uw]an pepper(?:corn)?",
    ],
    # NUTS
    "cashew": [r"\bcashew(?: nut)?$"],
    "chestnut": [r"chest ?nut$"],
    "walnut": [r"walnut(?: hal(?:f|ves))?$"],
    "peanut": [r"peanut$"],
    "almond": [r"almond$", r"macadamia(?: nut)?$"],
    "pistachio": [r"pistachio(?: nut)?$"],
    "pecan": [r"pecan(?: nut)?$"],
    "hazelnut": [r"hazel ?nut$"],
    "pine nut": [r"pine ?nut$"],
    "nut": [r"\bnut$", r"sacha inchi", r"acorns?$", r"butternuts?$"],
    # SEEDS
    "chia": [r"chia(?: seed)?"],
    "anise": [r"anise(?: seed)?"],
    "cardamom pod": [r"cardamom pod", r"cardamom seed"],
    "mustard seed": [r"mustard seed$"],
    "sesame": [r"sesame seeds?", r"sesame$"],
    "poppy": [r"poppy seeds?", r"poppy$"],
    "sunflower seed": [r"sunflower seed"],
    "flaxseed": [r"flaxseed$"],
    "seed": [r"\bseed$"],
    # VEGETABLES
    "spinach": [r"spinach$"],
    "kale": [r"\bkale$"],
}


class Ingredient:
    def __init__(self, phrase, ingredient) -> None:
        self.phrase = phrase
        self.id = None
        self.categories = []
        self.quantity = []
        self.name = ""
        self.synonyms = []
        self.regex = r""
        self.unit = ""

    def __str__(self) -> str:
        return self.name

    def __repr__(self) -> str:
        return self.name

    def __eq__(self, o: object) -> bool:
        return self.id == o.id


def get_cheese():
    return [key for key in list(dictionary.keys()) if re.search(r"\bcheese$")]



notes_and_hits = [
    {
        "name": "melon",
        "synonyms": [],
        "description": "A note of melon in wine brings a bright and fresh sweetness, often found in youthful whites, evoking the crisp juiciness of summer fruits.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "spice cake",
        "synonyms": [],
        "description": "This evokes the warmth and complexity of autumn, with notes of cinnamon, nutmeg, and clove mingling in rich, full-bodied wines.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "biscuit",
        "synonyms": [],
        "description": "It suggests a toasty, slightly yeasty quality, reminiscent of freshly baked bread, often found in aged sparkling wines.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "buttery",
        "synonyms": [],
        "description": "A creamy and rich descriptor, often associated with full-bodied white wines that have undergone malolactic fermentation, imparting a smooth, velvety texture.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "menthol",
        "synonyms": [],
        "description": "Adds a cool, refreshing lift to the aroma profile, providing a counterpoint to the richer, more dense fruit notes in some red wines.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "hazelnut",
        "synonyms": [],
        "description": "This note contributes a nutty, slightly sweet, and roasted dimension, often detected in wines aged in oak barrels.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "pear",
        "synonyms": [],
        "description": "A crisp, fresh fruit aroma that adds a delicate sweetness and acidity to lighter white wines, hinting at youthful vibrancy.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "birch leaf",
        "synonyms": [],
        "description": "Introduces a unique, slightly herbal and earthy tone, suggesting a wine's connection to its terroir and the freshness of nature.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "lily",
        "synonyms": [],
        "description": "A floral note that imparts elegance and a fragrant, aromatic lift, enhancing the complexity and allure of both white and sparkling wines.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "fruit",
        "synonyms": [],
        "description": "A broad descriptor that encompasses the essence of a wine's character, ranging from ripe, juicy berries in reds to succulent stone fruits in whites, highlighting the wine's vitality and flavor spectrum.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "dark cherry",
        "synonyms": [],
        "description": "Velvety whispers of dark cherry evoke moonlit orchards, promising depth and mystery in each sip.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "appel marmalade",
        "synonyms": [],
        "description": "The sunny, tangy sweetness of apple marmalade dances on the palate, blending nostalgia with a touch of sophistication.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "honey melon",
        "synonyms": [],
        "description": "Honey melon's gentle, luscious notes offer a refreshing embrace, like a soft, sweet melody in summer's heat.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "cardamom",
        "synonyms": [],
        "description": "Cardamom's exotic spice weaves through the wine, adding whispers of ancient markets and faraway lands.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "dried fig",
        "synonyms": [],
        "description": "The richness of dried fig lends a warm, earthy base, reminiscent of stories told beside a flickering fire.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "vanilla",
        "synonyms": [],
        "description": "A hint of vanilla, smooth and comforting, wraps around the senses like a soft, well-loved blanket.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "resin ",
        "synonyms": [],
        "description": "The intriguing scent of resin adds a mysterious depth, beckoning you into a forest at dawn, mist clinging to ancient trees.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "bread",
        "synonyms": [],
        "description": "The comforting aroma of freshly baked bread brings a heartwarming simplicity, grounding and familiar.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "straw",
        "synonyms": [],
        "description": "Straw offers a rustic touch, a reminder of open fields and endless skies, carrying the essence of tranquility.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "red apple",
        "synonyms": [],
        "description": "Crisp and invigorating, red apple's vibrant notes capture the joy of biting into the first apple of autumn.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "lime",
        "synonyms": [],
        "description": "Zesty and fresh, lime notes bring a vibrant, tangy acidity that brightens the palate, reminiscent of a crisp, summer day.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "apricot marmalade",
        "synonyms": [],
        "description": "Rich and sweet, with a touch of tartness, apricot marmalade notes envelop the senses in a luscious, fruity embrace.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "candy",
        "synonyms": [],
        "description": "Playful and sweet, candy notes evoke memories of childhood with their sugary, colorful burst of joy.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "lemon",
        "synonyms": [],
        "description": "Sharp and invigorating, lemon notes cut through with a clean, citrusy sharpness that refreshes with each sip.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "blueberry",
        "synonyms": [],
        "description": "Deep and complex, blueberry notes offer a harmonious blend of sweetness and acidity, wrapped in earthy undertones.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "cinnamon",
        "synonyms": [],
        "description": "Warm and spicy, cinnamon notes weave through the palate with a comforting, aromatic richness that's both exotic and familiar.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "dill",
        "synonyms": [],
        "description": "Fresh and herbaceous, dill notes add a delicate, green brightness, evoking the crispness of a garden in spring.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "flower meadow",
        "synonyms": [],
        "description": "Evocative and delicate, notes of a flower meadow transport you to a serene, blooming field with every breath.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "star anise",
        "synonyms": [],
        "description": "Mysterious and licorice-like, star anise notes provide a bold, intriguing spiciness that's both warm and inviting.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "mint",
        "synonyms": [],
        "description": "Cool and refreshing, mint notes sweep across the palate with a clean, invigorating burst of herbal clarity.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "bay leaf",
        "synonyms": [],
        "description": "A herbaceous and slightly astringent note reminiscent of the Mediterranean landscape.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "resinous",
        "synonyms": [],
        "description": "Evoking the dense, sticky essence of pine or sap, adding depth and complexity.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "grassy",
        "synonyms": [],
        "description": "Fresh and vibrant, akin to the smell of freshly cut lawn or green fields.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "fruit cake",
        "synonyms": [],
        "description": "Rich and decadent, with layers of dried fruits, nuts, and spices melded together.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "peruvian pepper",
        "synonyms": [],
        "description": "A unique spicy and slightly fruity note, offering a hint of exotic warmth.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "nutshell",
        "synonyms": [],
        "description": "Earthy and slightly bitter, capturing the essence of a forest floor in autumn.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0],
    },
    {
        "name": "liquorice",
        "synonyms": [],
        "description": "Sweet, yet slightly bitter and herbal, evoking childhood confectionary memories.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "stable",
        "synonyms": [],
        "description": "A rustic, earthy note with nuances of hay and leather, grounding and complex.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "olive",
        "synonyms": [],
        "description": "Briny and slightly bitter, reminiscent of Mediterranean groves and sunny days.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "kiwi fruit",
        "synonyms": [],
        "description": "Bright and tart, with a juicy sweetness that brings a burst of freshness.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "pear candy",
        "synonyms": [],
        "description": "Sweet and slightly floral, with the luscious aroma of ripe pears and sugary treats.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "tar",
        "synonyms": [],
        "description": "Intensely smoky and dark, with a depth that adds a brooding character to the profile.",
        "vector": [0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "cocoa bean",
        "synonyms": [],
        "description": "Rich and slightly bitter, evoking dark chocolate with a touch of earthiness.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "oat biscuit",
        "synonyms": [],
        "description": "Warm and comforting, with a sweet, toasty quality reminiscent of home baking.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "vanilla pod",
        "synonyms": [],
        "description": "Sweet and creamy, with a luxurious fragrance that envelops the senses.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "oat flake",
        "synonyms": [],
        "description": "Mild and grainy, with a natural sweetness and a comforting, soft texture.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "cake",
        "synonyms": [],
        "description": "Sweet and buttery, with hints of vanilla and a soft, indulgent texture.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "clementine",
        "synonyms": [],
        "description": "Zesty and sweet, with a vibrant citrus burst that’s refreshing and lively.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "fruit pie",
        "synonyms": [],
        "description": "Warm and inviting, filled with the sweet and tangy aromas of baked fruit and spices.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "boysenberry",
        "synonyms": [],
        "description": "Juicy and slightly tart, with a deep berry flavor that’s both bold and nuanced.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "ginger",
        "synonyms": [],
        "description": "A zesty and slightly spicy note that invigorates the palate with its fiery warmth.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "pineapple",
        "synonyms": [],
        "description": "A burst of tropical sweetness, balancing sugar and acidity for a refreshing tang.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "heather",
        "synonyms": [],
        "description": "Subtly floral and earthy, reminiscent of the wild, breezy landscapes where it thrives.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "apple",
        "synonyms": [],
        "description": "Crisp and clean, ranging from sweet to tart, evoking the freshness of orchard harvests.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "passion fruit",
        "synonyms": [],
        "description": "Exotic and intense, with a heady perfume and a tart, tropical flavor that dances on the tongue.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "black olive",
        "synonyms": [],
        "description": "Briny and rich, offering a savory depth with notes of earthiness and a touch of bitterness.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "chocolate",
        "synonyms": [],
        "description": "Luxuriously smooth and comforting, with a deep richness varying from sweet milk to bitter dark.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "apricot",
        "synonyms": [],
        "description": "Sweet and softly tangy, with a velvety, floral fruitiness that whispers of summer.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "milk coffee",
        "synonyms": [],
        "description": "Creamy and soothing, with a gentle coffee bitterness mellowed by the sweetness of milk.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "malty",
        "synonyms": [],
        "description": "Warm and comforting, with a toasty sweetness that recalls baked bread and autumn afternoons.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "dark cranberry",
        "synonyms": [],
        "description": "Tart and bold, with a deep, red fruit sharpness that awakens the senses.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "buckthorn",
        "synonyms": [],
        "description": "Intriguingly sour and sharp, with a wild, berry-like intensity that's both rare and refreshing.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "roasted almond",
        "synonyms": [],
        "description": "Nutty and warm, with a toasty richness that envelops the palate in comfort.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0],
    },
    {
        "name": "quince",
        "synonyms": [],
        "description": "Uniquely fragrant and tart, a rare treat that combines pear-like sweetness with a citrus edge.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "toast",
        "synonyms": [],
        "description": "Comfortingly familiar, with a golden, crispy warmth that evokes mornings bathed in sunlight.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 0.0],
    },
    {
        "name": "currant",
        "synonyms": [],
        "description": "Tart and tangy, with a berry brightness that adds a lively spark to any tasting.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "fruit candy",
        "synonyms": [],
        "description": "Playfully sweet, bursting with a rainbow of flavors that delight and entertain the taste buds.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "champignon",
        "synonyms": [],
        "description": "Earthy and subtle, with a savory depth that grounds the palate in forest freshness.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0],
    },
    {
        "name": "flowery",
        "synonyms": [],
        "description": "Delicately aromatic, painting the senses with a bouquet of spring's first blooms.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "blood grapefruit",
        "synonyms": [],
        "description": "Bold and bitter-sweet, offering a citrusy jolt with a ruby-red twist of complexity.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "almond",
        "synonyms": [],
        "description": "A nutty and slightly sweet flavor that evokes warmth and earthiness.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "balanced oak",
        "synonyms": [],
        "description": "Offers a harmonious woodiness without overpowering, lending a backbone of structure to the wine.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "salmiak",
        "synonyms": [],
        "description": "A distinctive salty-licorice note, often found in Nordic countries, adding depth and intrigue.",
        "vector": [0.0, 0.0, 1.0, 0.0, 1.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "ink",
        "synonyms": [],
        "description": "A deep, dark, slightly astringent note reminiscent of wet stone and graphite.",
        "vector": [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "white peach",
        "synonyms": [],
        "description": "Delicate and floral, with a juicy, succulent sweetness that’s both refreshing and aromatic.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "orange blossom",
        "synonyms": [],
        "description": "Fragrant and subtly sweet, like walking through an orchard in bloom.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "yuzu fruit",
        "synonyms": [],
        "description": "A tantalizing blend of tart and tangy, with hints of citrus zest and a unique floral undertone.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "honey",
        "synonyms": [],
        "description": "Sweet, rich, and comforting, evoking fields of flowers and summertime warmth.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0],
    },
    {
        "name": "green paprika",
        "synonyms": [],
        "description": "A crisp, slightly spicy and vegetal note that adds a fresh layer of complexity.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "cream filled pastry",
        "synonyms": [],
        "description": "Lusciously sweet with a hint of vanilla and buttery richness.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "grapefruit",
        "synonyms": [],
        "description": "Zesty and slightly bitter, offering a refreshing and invigorating citrus kick.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "honeycomb",
        "synonyms": [],
        "description": "A deeper, richer version of honey, with a waxy texture and complex layers of sweetness.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "smoked ham",
        "synonyms": [],
        "description": "Savory and smoky, with a hint of saltiness that evokes a sense of comfort and depth.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "cocoa",
        "synonyms": [],
        "description": "Dark and slightly bitter, evoking a sense of indulgence and depth.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "cherry",
        "synonyms": [],
        "description": "Juicy and vibrant, with a perfect balance of sweet and tart that dances on the palate.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "citrus",
        "synonyms": [],
        "description": "A burst of refreshing acidity, bringing light and zest to the wine’s profile.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "arctic bramble",
        "synonyms": [],
        "description": "A rare and delicate fruity note, combining sweetness with a hint of Arctic freshness.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "whitecurrant",
        "synonyms": [],
        "description": "Crisp and tart, with a delicate sweetness and a refreshing acidity.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "rhubarb",
        "synonyms": [],
        "description": "Tart and slightly earthy, adding a unique vegetal sweetness with a hint of sourness.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "red gooseberry",
        "synonyms": [],
        "description": "A lively and tart fruit note, with a nuanced sweetness and a hint of astringency.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "anise",
        "synonyms": [],
        "description": "Evokes the sweet, slightly spicy, and licorice-like aroma.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "whisky",
        "synonyms": [],
        "description": "Brings forth rich, warm notes of malt, oak, and smoky peat.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "creme brulee",
        "synonyms": [],
        "description": "Delivers the comforting sweetness of vanilla and caramelized sugar.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0],
    },
    {
        "name": "noble rot",
        "synonyms": [],
        "description": "Offers complex flavors of honey, dried fruit, and a touch of earthiness.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "wheat",
        "synonyms": [],
        "description": "Contributes a fresh, light, and slightly nutty essence.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "rye",
        "synonyms": [],
        "description": "Adds a spicy, grainy character with a hint of fruitiness.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "elegant oaky",
        "synonyms": [],
        "description": "Introduces refined notes of vanilla, toast, and a hint of smoke.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "apple compote",
        "synonyms": [],
        "description": "Brings a warm, cooked apple sweetness with hints of cinnamon.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "white chocolate",
        "synonyms": [],
        "description": "Provides a creamy, buttery sweetness with a delicate cocoa note.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "black tea",
        "synonyms": [],
        "description": "Offers a robust, slightly astringent, and earthy undertone.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "vermouth",
        "synonyms": [],
        "description": "Combines herbaceous, floral, and bitter elements for a complex profile.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "black pepper",
        "synonyms": [],
        "description": "Adds a sharp, piquant spiciness to the mix.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "dried cranberry",
        "synonyms": [],
        "description": "Introduces a tart, sweet, and slightly chewy fruit character.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "mocha",
        "synonyms": [],
        "description": "Melds the richness of coffee with the creamy sweetness of chocolate.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "dried plum",
        "synonyms": [],
        "description": "Offers a concentrated sweetness with a hint of tartness and earthiness.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "waffle",
        "synonyms": [],
        "description": "Delivers a comforting aroma of cooked batter with a hint of sweetness.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "clove",
        "synonyms": [],
        "description": "Adds a warm, spicy note with a hint of sweetness.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "perfume",
        "synonyms": [],
        "description": "Suggests a complex, floral, and sometimes fruity or spicy character.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "petrol",
        "synonyms": [],
        "description": "Brings a unique, mineral-like, slightly gasoline note, often found in aged Rieslings.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "toasted",
        "synonyms": [],
        "description": "Offers warm, comforting notes of toasted bread, nuts, or grains.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 0.0],
    },
    {
        "name": "apple tart cake",
        "synonyms": [],
        "description": "Invitingly sweet with a hint of rustic charm.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "berry",
        "synonyms": [],
        "description": "Bursting with juicy, fresh vibrancy.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "toasted bread",
        "synonyms": [],
        "description": "Comfortingly warm with a hint of earthiness.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 0.0],
    },
    {
        "name": "raspberry sorbet",
        "synonyms": [],
        "description": "Refreshingly tart with a sweet finish.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "blood orange",
        "synonyms": [],
        "description": "Boldly tangy with a deep citrus complexity.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "herbal",
        "synonyms": [],
        "description": "Subtly aromatic with a whisper of green freshness.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "strawberry",
        "synonyms": [],
        "description": "Delightfully sweet with a soft, summery essence.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "rowanberry",
        "synonyms": [],
        "description": "Distinctly tart with a wild, untamed edge.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "juniper berry",
        "synonyms": [],
        "description": "Crisp with a piney, almost mystical depth.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "sour cherry",
        "synonyms": [],
        "description": "Sharply tangy, awakening the palate with its vibrance.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "rye bread",
        "synonyms": [],
        "description": "Earthy with a robust, grainy character.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "blackcurrant",
        "synonyms": [],
        "description": "Deeply fruity with a lush, velvety richness.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "redcurrant",
        "synonyms": [],
        "description": "Brightly acidic, adding a lively sparkle.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "cinnamon-apple",
        "synonyms": [],
        "description": "Comfortingly warm, spiced with a sweet crispness.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "red pepper",
        "synonyms": [],
        "description": "Vividly sharp with a subtle, smoky sweetness.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "bog bilberry",
        "synonyms": [],
        "description": "Rare and wild, with a tart, haunting flavor.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "coffee flavoured chocolate",
        "synonyms": [],
        "description": "Luxuriously rich with a bittersweet complexity.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "balsamic",
        "synonyms": [],
        "description": "Richly tart, layered with a sweet, syrupy depth.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "shortbread",
        "synonyms": [],
        "description": "Buttery and crumbly, melting delightfully on the tongue.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "medicinal herb",
        "synonyms": [],
        "description": "Earthy and potent, with a healing, bitter edge.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "plum",
        "synonyms": [],
        "description": "A ripe, juicy plum note brings a sweet and slightly tart complexity, reminiscent of summer fruits.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "green pepper",
        "synonyms": [],
        "description": "The green pepper note introduces a fresh, slightly grassy, and crisp dimension, often found in Cabernet Franc wines.",
        "vector": [1.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "umami",
        "synonyms": [],
        "description": "Umami offers a savory taste depth, enhancing flavors with a rich and complex character.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "autumn apple",
        "synonyms": [],
        "description": "Autumn apple notes evoke the crisp, slightly tart flavors of freshly harvested apples, adding brightness and freshness.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "grainy",
        "synonyms": [],
        "description": "A grainy note suggests a subtle, earthy texture reminiscent of cereals or bread, adding complexity to the wine's profile.",
        "vector": [0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "eucalyptus",
        "synonyms": [],
        "description": "Eucalyptus imparts a cool, minty, and slightly herbal aroma, adding a refreshing and invigorating layer.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "cognac",
        "synonyms": [],
        "description": "A cognac note adds a warm, rich, and slightly spicy character, suggesting aged elegance and depth.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "peach candy",
        "synonyms": [],
        "description": "Peach candy notes bring a playful, sweet, and fruity essence, reminiscent of sugared summer fruits.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "citrus marmalade",
        "synonyms": [],
        "description": "Citrus marmalade introduces a sweet and tangy burst, combining the zestiness of citrus with a sugary finish.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "sorrel",
        "synonyms": [],
        "description": "Sorrel contributes a unique, slightly tangy and herbaceous flavor, adding a refreshing and slightly sour twist.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "white pepper",
        "synonyms": [],
        "description": "White pepper adds a subtle, spicy kick, offering a gentle heat that lifts the wine's aromatic profile.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "red berry",
        "synonyms": [],
        "description": "Red berry notes encapsulate the juicy, sweet, and slightly tart flavors of strawberries and raspberries, adding a vibrant fruitiness.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "berry yogurt",
        "synonyms": [],
        "description": "Berry yogurt combines the creamy, tangy qualities of yogurt with the sweet, lush flavors of mixed berries.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "smoked paprika",
        "synonyms": [],
        "description": "Smoked paprika lends a smoky, slightly spicy, and rich dimension, evoking warmth and complexity.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "fig",
        "synonyms": [],
        "description": "Fig introduces a sweet, jammy, and slightly nutty flavor, adding richness and a hint of decadence.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "rose petals",
        "synonyms": [],
        "description": "Rose petals offer a delicate, floral aroma, adding elegance and a soft, perfumed character.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "mushroom",
        "synonyms": [],
        "description": "Mushroom notes bring an earthy, umami-rich dimension, grounding the wine with a sense of depth and savoriness.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "cherry-blossom",
        "synonyms": [],
        "description": "Cherry-blossom adds a gentle, floral sweetness, infusing the wine with a spring-like freshness and delicacy.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "raspberry marmalade",
        "synonyms": [],
        "description": "Raspberry marmalade combines the tartness of raspberries with a sweet, concentrated depth, adding a luscious fruitiness.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "velvety oak",
        "synonyms": [],
        "description": "Velvety oak imparts a smooth, rich texture along with hints of vanilla and spice, adding complexity and warmth.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "strawberry cake",
        "synonyms": [],
        "description": "Like a slice of summer, evoking the sweetness and lightness of ripe strawberries.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "ginger snap",
        "synonyms": [],
        "description": "A bite that snaps with warmth and spice, reminiscent of cozy, aromatic evenings.",
        "vector": [0.0, 0.0, 1.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "leather",
        "synonyms": [],
        "description": "A complex, deep note that brings to mind the richness of well-aged wine or the interior of a cherished library.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "dark raspberry",
        "synonyms": [],
        "description": "A juicy, dark burst of flavor, marrying sweetness with a touch of earthy depth.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "coriander seed",
        "synonyms": [],
        "description": "Aromatic and slightly citrusy, with a spicy, nutty finish that dances on the palate.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "grain",
        "synonyms": [],
        "description": "Earthy and comforting, embodying the heartiness of the field and the breadbasket.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "jasmine",
        "synonyms": [],
        "description": "Delicately floral, with a whisper of sweet perfume that lingers like a serene, moonlit garden.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "date",
        "synonyms": [],
        "description": "Rich and sweet, conjuring images of opulent desserts and Middle Eastern bazaars.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "cloudberry",
        "synonyms": [],
        "description": "A rare, tart sweetness, evocative of northern wilderness and the glow of midnight suns.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "walnut",
        "synonyms": [],
        "description": "Earthy and robust, a blend of crunch and bitterness that grounds and satisfies.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "nectarine",
        "synonyms": [],
        "description": "Bright and sunny, with a juicy sweetness undercut by a hint of acidity.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "smoky",
        "synonyms": [],
        "description": "A mysterious, lingering essence that evokes fireside gatherings and ancient traditions.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "asparagus",
        "synonyms": [],
        "description": "Fresh and green, with a distinctive, slightly bitter undertone that intrigues the palate.",
        "vector": [1.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "pencil lead",
        "synonyms": [],
        "description": "Minerally and sharp, suggesting precision and a certain austere elegance.",
        "vector": [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "coconut",
        "synonyms": [],
        "description": "Tropical and creamy, whisking you away to sandy shores with its sweet, lush bounty.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "peach",
        "synonyms": [],
        "description": "Summery and soft, a gentle caress of sweetness with a velvety finish.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "saddle leather",
        "synonyms": [],
        "description": "Rich and evocative, a testament to craftsmanship and the passage of time.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "spruce shoot",
        "synonyms": [],
        "description": "Crisp and clean, with a hint of resinous freshness that awakens the senses.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "bourbon vanilla",
        "synonyms": [],
        "description": "Deep and sultry, a luxurious swirl of sweetness with a smoky, intoxicating edge.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "gingerbread",
        "synonyms": [],
        "description": "Warm and festive, a comforting blend of spices that tastes like holidays and homecomings.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "paprika",
        "synonyms": [],
        "description": "A warm, earthy note with a gentle heat, reminiscent of the vibrant red spice it's named after.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "chocolate",
        "synonyms": [],
        "description": "Rich and indulgent, evoking the comfort and depth of dark cocoa.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "rose",
        "synonyms": [],
        "description": "Delicately floral, with a soft, aromatic sweetness that whispers of romance.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "mineral",
        "synonyms": [],
        "description": "Crisp and refreshing, bringing to mind the purity of rain-kissed rocks and soil.",
        "vector": [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "rum",
        "synonyms": [],
        "description": "Sugarcane's complexity distilled into a sweet, slightly spicy, and warm embrace.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "thyme",
        "synonyms": [],
        "description": "Herbal and slightly earthy, with a whisper of the Mediterranean breeze.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "biscuit dough",
        "synonyms": [],
        "description": "Comfortingly warm and buttery, hinting at sweetness and home-baked goodness.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "chamomile",
        "synonyms": [],
        "description": "Gentle and soothing, with a soft, floral, and slightly sweet nature.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "griddle pancake",
        "synonyms": [],
        "description": "The essence of cozy mornings, with warm, golden notes and a hint of vanilla.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "basil",
        "synonyms": [],
        "description": "Fresh and vibrant, a green note with a peppery edge that dances on the palate.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "banana",
        "synonyms": [],
        "description": "Tropical and sweet, with a creamy, ripe fruitiness that's instantly recognizable.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "dried pineapple",
        "synonyms": [],
        "description": "Concentrated sweetness and tropical flair, rich with a chewy, fruity intensity.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "blackcurrant leaf",
        "synonyms": [],
        "description": "Green and slightly fruity, with a tangy, herbaceous note that's refreshingly unique.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "chestnut",
        "synonyms": [],
        "description": "Earthy and nutty, with a rich, sweet undercurrent that's warmly inviting.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "violet",
        "synonyms": [],
        "description": "A delicate floral sweetness, elegant and slightly powdery in its allure.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "spice",
        "synonyms": [],
        "description": "A thrilling blend of warmth and mystery, evoking exotic destinations and colorful markets.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "dark chocolate",
        "synonyms": [],
        "description": "The bittersweet edge of cocoa deepened into something dense, complex, and indulgent.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "currant leaf",
        "synonyms": [],
        "description": "Similar to blackcurrant leaf, offering a green and slightly tangy berry nuance.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "chokeberry",
        "synonyms": [],
        "description": "Tart and tannic, with a deep, dark fruitiness that's intriguing and bold.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "creamy",
        "synonyms": [],
        "description": "Smooth and rich, a luxurious texture that coats the palate with a velvety touch.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "butter popcorn",
        "synonyms": [],
        "description": "A delightful hint of creamy butter with the warm, toasted aroma of freshly popped corn.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "persimmon",
        "synonyms": [],
        "description": "A lush sweetness with a honeyed, slightly tangy finish reminiscent of autumn's bounty.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "forest floor",
        "synonyms": [],
        "description": "Earthy and rich, evoking the damp, mossy blanket of a forest underfoot.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "cream toffee",
        "synonyms": [],
        "description": "Velvety and indulgent, like melted toffee with a smooth, creamy backdrop.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "coriander",
        "synonyms": [],
        "description": "A lively, citrusy spice with hints of sage and lemon, offering a refreshing complexity.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "dark berry",
        "synonyms": [],
        "description": "Deep and mysterious, bursting with the essence of ripe, dark berries on a summer's eve.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "raspberry-chocolate",
        "synonyms": [],
        "description": "A seductive duo of tart raspberry and luxurious dark chocolate, both rich and enticing.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "apple blossom",
        "synonyms": [],
        "description": "Delicately floral with the crisp, airy sweetness of spring apple blossoms.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "cedar",
        "synonyms": [],
        "description": "A robust and woodsy aroma, evoking the timeless grace of cedar forests.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "orange marmalade",
        "synonyms": [],
        "description": "Sweet and tangy, with the vibrant zest of citrus and a sticky, sweet finish.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "damson",
        "synonyms": [],
        "description": "A rich, plummy note with a hint of almond, dark and sumptuous.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "truffle",
        "synonyms": [],
        "description": "Earthy and opulent, with a deep, musky allure that's unmistakably gourmet.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "christmas apple",
        "synonyms": [],
        "description": "Warm and spiced, reminiscent of apples mulled with cinnamon and cloves by the fireside.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "mandarin",
        "synonyms": [],
        "description": "Bright and zesty, capturing the sunlit sparkle of fresh mandarins.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "christmas spice",
        "synonyms": [],
        "description": "A cozy melange of cinnamon, nutmeg, and cloves, wrapped in holiday warmth.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "raspberry",
        "synonyms": [],
        "description": "Vibrantly sweet and tart, like a burst of fresh raspberries on a summer day.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "green pear",
        "synonyms": [],
        "description": "Crisp and juicy, with a fresh, lightly floral sweetness that's refreshingly light.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "mango",
        "synonyms": [],
        "description": "Tropical and sweet, with a lush, mouthwatering richness that transports you to an island paradise.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "brandyish",
        "synonyms": [],
        "description": "Warm and velvety, with a rich, aged depth and notes of caramel and wood.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "liquorice root",
        "synonyms": [],
        "description": "Dark and mysterious, offering a sweet, anise-like flavor that's both complex and comforting.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "nutty",
        "synonyms": [],
        "description": "A comforting embrace of earthiness and warmth, reminiscent of autumn evenings by the fire.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "green gooseberry",
        "synonyms": [],
        "description": "Vibrantly tart and refreshing, evoking a crisp, sunny morning in the countryside.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "fruity",
        "synonyms": [],
        "description": "A joyful burst of summer orchard fruits, dancing lively on the palate.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "maraschino cherry",
        "synonyms": [],
        "description": "Sweet, with a hint of nostalgia, like a cherished memory from a festive celebration.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "funnel chanterelle",
        "synonyms": [],
        "description": "Earthy and rich, a subtle whisper of the forest's hidden treasures.",
        "vector": [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "yellow plum",
        "synonyms": [],
        "description": "Delicately sweet with a hint of tartness, capturing the essence of late summer's bounty.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "milky cocoa",
        "synonyms": [],
        "description": "Smooth and comforting, a velvety whisper of chocolatey indulgence.",
        "vector": [0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "apricot",
        "synonyms": [],
        "description": "Bright and sun-kissed, with a tender sweetness that softly lingers.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "salty almond",
        "synonyms": [],
        "description": "A delightful contrast of savory nuttiness, evoking a sense of seaside adventures.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "marzipan",
        "synonyms": [],
        "description": "Sweetly almond, a dreamy confection that transports you to a festive market square.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 1.0],
    },
    {
        "name": "dried date",
        "synonyms": [],
        "description": "Deeply sweet and rich, a treasure trove of desert warmth.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "pear marmalade",
        "synonyms": [],
        "description": "Lusciously sweet and fragrant, a spread of autumn harvest on your palate.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "pudding",
        "synonyms": [],
        "description": "Creamy and comforting, a spoonful of blissful indulgence.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "tropical fruit",
        "synonyms": [],
        "description": "Exotically sweet, a carnival of sunshine and vibrant colors.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "pomelo",
        "synonyms": [],
        "description": "Fresh and zesty, a splash of citrus brightness to awaken the senses.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "caramel",
        "synonyms": [],
        "description": "Decadently sweet, a silky ribbon of golden indulgence.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "salted caramel",
        "synonyms": [],
        "description": "A tantalizing dance of sweet and savory, a delightful intrigue.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "elderflower",
        "synonyms": [],
        "description": "Delicately floral, a gentle whisper of spring's first bloom.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "brioche",
        "synonyms": [],
        "description": "Buttery and rich, a soft embrace of comforting luxury.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "yellow raisin",
        "synonyms": [],
        "description": "Sweetly sun-dried, a nugget of golden warmth and nostalgia.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "allspice",
        "synonyms": [],
        "description": "Allspice evokes the warm, sweet-spicy aroma of winter holidays.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "cranberry",
        "synonyms": [],
        "description": "Cranberry brings a tart, vibrant red berry burst, perfect for autumn.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "milk chocolate",
        "synonyms": [],
        "description": "Milk chocolate offers a creamy, comforting sweetness with a velvety texture.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0],
    },
    {
        "name": "rosemary",
        "synonyms": [],
        "description": "Rosemary adds a woodsy, aromatic lift, reminiscent of Mediterranean landscapes.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "green apple",
        "synonyms": [],
        "description": "Green apple provides a crisp, juicy tartness, refreshing the palate.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "oak",
        "synonyms": [],
        "description": "Oak infuses a robust, toasty richness with hints of vanilla.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "tea",
        "synonyms": [],
        "description": "Tea imparts a delicate, soothing earthiness with subtle floral notes.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "raisin",
        "synonyms": [],
        "description": "Raisin delivers a sun-kissed sweetness with a chewy, dried fruit essence.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "pine",
        "synonyms": [],
        "description": "Pine introduces a fresh, resinous sharpness, akin to a forest after rain.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "dandelion",
        "synonyms": [],
        "description": "Dandelion contributes a slightly bitter, grassy note, grounding and herbal.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "sour orange",
        "synonyms": [],
        "description": "Sour orange offers a tangy, citrusy zing, brightening dishes with its acidity.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "balanced vanilla",
        "synonyms": [],
        "description": "Balanced vanilla presents a sweet, creamy smoothness, universally comforting.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "barley bread",
        "synonyms": [],
        "description": "Barley bread suggests a hearty, grainy texture with a slightly nutty flavor.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0],
    },
    {
        "name": "greencurrant",
        "synonyms": [],
        "description": "Greencurrant adds a tart, zesty punch, vibrant and invigorating.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "orange",
        "synonyms": [],
        "description": "Orange brings a sunny, sweet citrus burst, full of vitamin joy.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "fennel",
        "synonyms": [],
        "description": "Fennel offers an aniseed-like sweetness, crisp and refreshing.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "rose hip",
        "synonyms": [],
        "description": "Rose hip introduces a tangy, floral vitamin C kick, subtly sweet and tart.",
        "vector": [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "nut croquant",
        "synonyms": [],
        "description": "Nut croquant provides a caramelized, crunchy nuttiness, rich and satisfying.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "woody",
        "synonyms": [],
        "description": "Woody evokes the essence of a dense forest, grounding with a matured depth.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "hay",
        "synonyms": [],
        "description": "Hay brings a dry, sweet earthiness, reminiscent of late summer fields.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0],
    },
    {
        "name": "nettle",
        "synonyms": [],
        "description": "A green, slightly herbaceous note with a touch of earthiness and freshness.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "toffee",
        "synonyms": [],
        "description": "Rich, buttery sweetness with a caramel-like finish that lingers pleasantly.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "coffee",
        "synonyms": [],
        "description": "Deep, roasted aromas with hints of bitterness and complexity akin to a freshly brewed cup.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "yellow apple",
        "synonyms": [],
        "description": "Bright and crisp, embodying the perfect balance of sweetness and acidity.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "dark plum",
        "synonyms": [],
        "description": "Lush and juicy, with a deep fruity sweetness and subtle tartness.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "highbush blueberry",
        "synonyms": [],
        "description": "Vibrant and slightly tart, encapsulating the essence of fresh blueberries with a hint of sweetness.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "lingonberry",
        "synonyms": [],
        "description": "Tart and slightly sweet, with a unique berry freshness that invigorates the palate.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "soft liquorice",
        "synonyms": [],
        "description": "Gentle yet unmistakable, with a sweet, earthy profile and a hint of anise.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "herb",
        "synonyms": [],
        "description": "A refreshing and aromatic note that evokes a sense of green, leafy freshness.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "pepper",
        "synonyms": [],
        "description": "Spicy and invigorating, adding a lively kick and depth to the aroma profile.",
        "vector": [0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "exotic fruit",
        "synonyms": [],
        "description": "A tantalizing mix of sweetness and acidity, bursting with tropical flavors.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "kumquat",
        "synonyms": [],
        "description": "A distinct, tangy citrus note with a sweet outer layer and a sour center.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "blackberry",
        "synonyms": [],
        "description": "Juicy and rich, with a perfect blend of sweetness and tartness.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "gooseberry",
        "synonyms": [],
        "description": "A unique, tangy fruitiness with an underlying sweet and sour character.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "dried herbal",
        "synonyms": [],
        "description": "Concentrated and aromatic, evoking the warmth and earthiness of sun-dried herbs.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "vanilla-oak",
        "synonyms": [],
        "description": "Smooth and creamy with a woody depth, adding warmth and richness.",
        "vector": [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0],
    },
    {
        "name": "raspberry candy",
        "synonyms": [],
        "description": "Sweet and fruity, with a vibrant berry flavor that's reminiscent of childhood treats.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "lovage",
        "synonyms": [],
        "description": "Earthy and slightly celery-like, with a savory depth that adds complexity.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "lychee",
        "synonyms": [],
        "description": "Exotic and floral, with a perfumed sweetness that's both refreshing and captivating.",
        "vector": [1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0],
    },
    {
        "name": "tomato leaf",
        "synonyms": [],
        "description": "Green and vegetal, with a distinct freshness that's reminiscent of a garden after the rain.",
        "vector": [0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0],
    },
]



import re

from .drinks import *
from .fruit import *
from .nuts import *
from .vegetables import *


def ing_ends_with(ingredient, suffixes):
    return any(re.search(rf"{r}$", ingredient, flags=re.IGNORECASE) for r in suffixes)


def is_fruit_stone(ingredient):
    return ing_ends_with(ingredient, FRUIT_STONE)


def is_fruit_berry(ingredient):
    return ing_ends_with(ingredient, FRUIT_BERRY)


def is_fruit_melon(ingredient):
    return ing_ends_with(ingredient, FRUIT_MELON)


def is_fruit_citrus(ingredient):
    return ing_ends_with(ingredient, FRUIT_CITRUS)


def is_fruit_tropical(ingredient):
    return ing_ends_with(ingredient, FRUIT_TROPICAL)


def is_fruit(ingredient):
    return ing_ends_with(ingredient, FRUIT_DEFAULT)


def is_nut(ingredient):
    return ing_ends_with(ingredient, NUTS)


def is_vegetable_root(ingredient):
    return ing_ends_with(ingredient, VEG_ROOT)


def is_vegetable(ingredient):
    return ing_ends_with(ingredient, VEG_DEFAULT)


def is_vegetable_green(ingredient):
    return ing_ends_with(ingredient, VEG_GREEN)


def is_drink(title=""):
    return ing_ends_with(title, DRINKS)


TAG_VEGETABLES = "vegetables"
TAG_GREENS = "greens"
TAG_FRUIT = "fruits"
TAG_FRUIT_TROPICAL = "tropical fruits"
TAG_NUTS = "nuts"
TAG_BERRY = "berries"
TAG_VEGETARIAN = "vegetarian"
TAG_VEGAN = "vegan"


def tag_ingredients(ingredients=[]):
    """
    Given a list of ingredients, return a list of tags.
    """
    tags = []

    labellers = [
        (is_vegetable, TAG_VEGETABLES),
        (is_vegetable_green, TAG_GREENS),
        (is_fruit, TAG_FRUIT),
        (is_nut, TAG_NUTS),
        (is_fruit_tropical, TAG_FRUIT_TROPICAL),
        (is_fruit_berry, TAG_BERRY),
    ]

    for labeller, tag in labellers:
        for ing in ingredients:
            if labeller(ing):
                tags.append(tag)
                break

    return list(set(tags))


def tag_title(title=""):
    """
    Given a title, return a list of tags.
    """
    tags = []

    if re.search(r"\b(?:greens|vegs?|veggies?|vegetables?)\b", title):
        tags.append(TAG_VEGETABLES)
    if re.search(r"\b\fruit[sy]?\b", title):
        tags.append(TAG_FRUIT)
    if re.search(r"\b(?:nuts?|nutty)\b", title):
        tags.append(TAG_NUTS)
    if re.search(r"\b(?:berries?|berry)\b", title):
        tags.append(TAG_BERRY)
    if re.search(r"\bvegetarian\b", title):
        tags.append(TAG_VEGETARIAN)
    if re.search(r"\bvegan\b", title):
        tags.append(TAG_VEGAN)
    if re.search(r"\b(?:tropical|tutti.?frutti|exotic fruits?)\b", title):
        tags.append(TAG_FRUIT_TROPICAL)

    return list(set(tags))


def tag_recipe(title="", ingredients=[]):
    """
    Given a title and a list of ingredients, return a list of tags.
    """
    tags = []

    tags.extend(tag_title(title))
    tags.extend(tag_ingredients(ingredients))

    return list(set(tags))



from .data import meat
from .data.constants import (
    colors,
    sizes,
    states,
    u_all_values,
    u_imperial_values,
    u_metric_values,
    u_misc_values,
    word_numbers,
)
import re

range_separators = [r"-", r"to", r"–", r"or"]

def one_of(l):
    return r"|".join(l)

N_PREP = re.compile(rf"\b(?:each of(?= )|of each(?= )|of an?(?= )|of(?= )|an?(?= )|each,(?= )|each(?= ))")
N_WORD = re.compile(rf"\b(?:{one_of(word_numbers)})\b")
N_FRACTION = re.compile(r"\d+ ?/ ?\d+")
N_DECIMAL = re.compile(r"\d+\.\d+")
N_WHOLE = re.compile(r"\d+(?![/\.])")
N_COMPOSED = re.compile(rf"{N_WHOLE.pattern} {N_FRACTION.pattern}")
NUMBER = re.compile(
    rf"(?:"
    rf"{N_WORD.pattern}(?= |$)"
    rf"|"
    rf"{N_DECIMAL.pattern}"
    rf"|"
    rf"{N_FRACTION.pattern}"
    rf"|"
    rf"{N_WHOLE.pattern}(?: {N_FRACTION.pattern})?"
    rf")"
)

R_SEP = re.compile(rf" ?(?:{one_of(range_separators)}) ?")
RANGE = re.compile(rf"(?:" rf"{NUMBER.pattern}" rf"{R_SEP.pattern}" rf"{NUMBER.pattern}" rf")")

MOD = re.compile(
    rf"(?:"
    rf"\b\w+[- ]?(?:less|free|ful)\b"
    rf"|"
    rf"\b(?:\w+ly )?(?:(?:\w|-)+-|un|pre|extra|over|de)?(?:{one_of(states)})(?:-[\w-]+)?\b"
    rf"|"
    rf"\b(?:low|reduced|high|non)[- ]?(?:\w+)\b"
    rf")"
)

MOD_SEP = re.compile(r"(?:(?: ?,)? or | (?: ?,)? and/or | ?, ?|(?: ?,)? and | ?& ?| to | )")
MODS = re.compile(rf"(?:{MOD.pattern}{MOD_SEP.pattern})*{MOD.pattern}")

COLOR = re.compile(rf"(?:" rf"\b(?:{one_of(colors)})\b" rf")")
COLORS = re.compile(rf"(?:{COLOR.pattern}{MOD_SEP.pattern})*{COLOR.pattern}")

SIZE = re.compile(rf"(?:\b(?:{one_of(sizes)})(?:[- ]sized)?\b)")
SIZES = re.compile(rf"(?:{SIZE.pattern}{MOD_SEP.pattern})*{SIZE.pattern}")

U = re.compile(r"(?:(?<![a-z])(?:" + one_of(u_all_values) + r")(?![a-z]))")
U_IMPERIAL = re.compile(r"(?:(?<![a-z])(?:" + one_of(u_imperial_values) + r")(?![a-z]))")
U_METRIC = re.compile(r"(?:(?<![a-z])(?:" + one_of(u_metric_values) + r")(?![a-z]))")
U_MISC = re.compile(
    rf"(?:(?:{N_PREP.pattern} )?(?:{SIZES.pattern} {MOD_SEP.pattern}?)?(?:{MODS.pattern} )?(?<![a-z])(?:"
    + one_of(u_misc_values)
    + r")(?![a-z–-]))"
)
UNIT = re.compile(rf"(?:(?:(?:generous|heaping|heaped) )?{U.pattern}\.?)")

Q = re.compile(rf"(?:{RANGE.pattern}|{NUMBER.pattern})(?!-)")
Q_UNIT = re.compile(rf"(?:{Q.pattern}[ -]?{UNIT.pattern})")
Q_SIZE = re.compile(rf"(?:{Q.pattern} {SIZE.pattern})")

Q_COMPOSED = re.compile(
    rf"(?:"
    rf"{Q.pattern} ?{U_IMPERIAL.pattern}\.? ?{Q.pattern} ?{U_IMPERIAL.pattern}\.?"
    rf"|"
    rf"{Q.pattern} ?{U_METRIC.pattern}\.? ?{Q.pattern} ?{U_METRIC.pattern}\.?"
    rf")"
)

Q_DIMS = re.compile(
    rf"(?:"
    rf"(?:{NUMBER.pattern}[- –]?{UNIT.pattern})"
    rf" ?(?:by|x) ?"
    rf"(?:{NUMBER.pattern}[- –]?{UNIT.pattern})"
    rf")"
)
Q_UNIT_MISC = re.compile(
    rf"(?:"
    rf"(?:(?P<multiplier>{Q.pattern} )?(?P<quantity>{Q.pattern})-(?P<unit>{UNIT.pattern}))"
    rf" (?P<misc>{U_MISC.pattern})"
    rf")"
)

MULTIPLIER = re.compile(rf"(?:(?P<multiplier>{Q.pattern}) ?[x*] ?)")

Q_UNIT_RANGE = re.compile(
    rf"(?:" rf"{Q_COMPOSED.pattern}{R_SEP.pattern}{Q_COMPOSED.pattern}" rf"|" rf"{Q_UNIT.pattern}{R_SEP.pattern}{Q_UNIT.pattern}" rf")"
)

QUANTITY = re.compile(
    rf"(?:"
    rf"(?:(?P<multiplier>{Q.pattern}) ?[x*] ?)?"
    rf"(?P<quantity>{Q_DIMS.pattern}|{Q_UNIT_RANGE.pattern}|{Q_COMPOSED.pattern}|{Q_UNIT.pattern}|{Q.pattern}|{UNIT.pattern})?"
    rf"(?:"
    rf"(?: ?/ ?| or )"
    rf"(?:(?P<multiplier_alt>{Q.pattern}) ?[x*] ?)?"
    rf"(?P<quantity_alt>{Q_DIMS.pattern}|{Q_UNIT_RANGE.pattern}|{Q_COMPOSED.pattern}|{Q_UNIT.pattern}|{Q.pattern}|{UNIT.pattern})?"
    rf")?"
    rf"(?: ?(?P<misc_size>{SIZES.pattern})?{MOD_SEP.pattern}?(?P<misc_mods>{MODS.pattern})? ?(?P<extra_misc>{U_MISC.pattern}))?"
    rf")"
)

START_IRREG = re.compile(r"(?:sliced |cut |\w+ into |(?:\w+ed )?in |with(?:out)? |from |- |on |to (?=[a-z])|for |weighing |mixed (?:into |with |to |in )|is )")
START_POST_MOD = re.compile(r" ?, ?")
START_ALT_ING = re.compile(r"(?: or | and | & )")
POST_UNIT = re.compile(rf"(?:(?:{one_of(u_misc_values)}\b)(?=$|{START_POST_MOD.pattern}|{START_ALT_ING.pattern}| {START_IRREG.pattern}))")

END_ING = re.compile(rf"$| {START_IRREG.pattern}|{START_POST_MOD.pattern}| {POST_UNIT.pattern}|{START_ALT_ING.pattern}")

IRREG_POST_MODS = re.compile(
    rf"(?P<irreg_post_mod>" rf"{START_IRREG.pattern}[^,]*?(?= ?, ?| or | and |$)" rf")"
)

INGREDIENT = re.compile(
    rf"(?:about |approx(?:imately)? |around |plus |additional |extra |to taste |more )?"
    rf"(?:{QUANTITY.pattern} ?)?"
    rf"(?:or so |or about |about |approximately |around |per person )?"
    rf"(?:{N_PREP.pattern} )?"
    rf"(?:(?P<size>{SIZES.pattern}){MOD_SEP.pattern})?"
    rf"(?:(?P<pre_mod>{MODS.pattern}){MOD_SEP.pattern})?"
    rf"(?:(?P<color>{COLORS.pattern}) )?"
    rf"(?P<rest>"
    rf"(?:(?P<ingredient>.+?(?={END_ING.pattern})))?"
    rf"(?: ?(?P<post_unit>{POST_UNIT.pattern}))?"
    rf"(?: ?{IRREG_POST_MODS.pattern})?"
    rf"(?: ?, (?P<post_mod>.+?(?= or | and | & |$)))?"
    rf"(?:(?: or | and | & )(?P<ingredient_alt>{Q.pattern}.*))?"
    rf")"
)

PROTEIN = re.compile(one_of(
    [
        rf"""\b(?P<{key.replace(' ', '_')}>{one_of(values)})\b(?:$|.*(?P<{key.replace(' ', '_')}_portion>{
                one_of(meat.portions[
                    meat.type_portions[key] if key in meat.type_portions else 'all'
                ] + meat.portions['general'])
            }))"""
        for key, values in meat.dictionary.items()
    ]
))

PORTION = re.compile(one_of(meat.portions["all"]))

# tests = [
#     "175g/6oz piece smoked pancetta , rind removed",
#     "1 inch x 2 inch large knob ginger",
#     "1/4 cup celery , finely chopped",
#     "3-4 lbs beef round steak",
#     "1 1/2 head celery",
#     "1kg 50g beef",
#     "100ml/3 1/2fl oz double cream",
#     "1 1/2-2kg/3lb 5oz - 4lb 8oz lamb shoulder",
#     "5 1/2 cloves garlic , crushed",
#     "5 tsp cloves",
#     "5 garlic cloves to taste, crushed",
#     "3 3-ounce bags of chilli powder, smoked whoole",
#     "1 x 6-bone rack of lamb",
#     "1 1/2 big 6-bone racks of lamb",
#     "1 big rack of lamb or 2 megapints",
#     "freshly ground black pepper to taste",
#     "3 bay leaves",
#     "7-8 cinnamon sticks",
#     "1 thick crusted baguette",
#     "small bunch tarragon , roughly chopped",
#     "3 handfuls fresh, raw, small shelled prawns",
# ]

# for test in tests:
#     pprint(test)
#     pprint(re.search(INGREDIENT, test).groupdict())

# print(
#     re.search(INGREDIENT, "freshly ground black pepper to taste").groupdict()
# )



[
    "onion",
    "tomato",
    "carrot",
    "potato",
    "zucchini",
    "spinach",
    "cucumber",
    "chive",
    "cabbage",
    "eggplant",
    "leek",
    "lettuce",
    "asparagus",
    "vegetable",
    "tomatillo",
    "radish",
    "parsnip",
    "beet",
    "turnip",
    "okra",
    "kale",
    "arugula",
    "jicama",
    "rhubarb",
    "rutabaga",
    "aubergine",
    "courgette",
    "arrowroot",
    "escarole",
    "beetroot",
    "gherkin",
    "tapioca",
    "wasabi",
    "yam",
    "radicchio",
    "capsicum",
    "kumara",
    "stevia",
    "celeriac",
    "swede",
    "endive",
    "mesclun",
    "cassava",
    "chayote",
    "frisee",
    "brinjal",
    "cornichons",
    "kohlrabi",
    "fiddlehead",
    "rapini",
    "daikon",
    "tomatoe",
    "bottlegourd",
    "marrow",
    "ramp",
    "chard",
    "karela",
    "tatsoi",
    "kucai",
    "mirliton",
    "mizuna",
    "ube",
    "vidalia",
    "yuca",
    "yucca",
]



grape_pool = [
    "Sauvignon Blanc",
    "Muscadelle",
    "Pinot Gris",
    "Riesling",
    "Albariño",
    "Chardonnay",
    "Garganega",
    "Fiano",
    "Pinot Meunier",
    "Viognier",
    "Grecanico",
    "Verdejo",
    "Grenache Blanc",
    "Malvasia",
    "Grüner Veltliner",
    "Merlot",
    "Corvina",
    "Zweigelt",
    "Chenin Blanc",
    "Molinara",
    "Rondinella",
    "Arneis",
    "Pinot Noir",
    "Cabernet Franc",
    "Cabernet Sauvignon",
    "Petit Verdot",
    "Nebbiolo",
    "Tempranillo",
    "Barbera",
    "Sangiovese",
    "Cannonau",
    "Carignan",
    "Torrontés",
    "Savagnin",
    "Carricante",
    "Catarratto",
    "Falanghina",
    "Zibibbo",
    "Sylvaner",
    "Pinot Blanc",
    "Pecorino",
    "Verdicchio",
    "Macabeo",
    "Ribolla Gialla",
    "Trebbiano",
    "Tannat",
    "Marsanne",
    "Vilana",
    "Shiraz",
    "Grenache Noir",
    "Syrah",
    "Caladoc",
    "Castelão",
    "Tinta Roriz",
    "Alicante Bouschet",
    "Touriga Nacional",
    "Verdelho",
    "Antão Vaz",
    "Pinot Grigio",
    "Petit Manseng",
    "Gros Manseng",
    "Colorino",
    "Malbec",
    "Carmenère",
    "Monastrell",
    "Garnacha",
    "Grillo",
    "Tinta Barroca",
    "Cinsault",
    "Perricone",
    "Mourvèdre",
    "Pinotage",
    "Montepulciano",
    "Negroamaro",
    "Cabernet",
    "Zinfandel",
    "Moscato",
    "Arinto",
    "Grenache",
    "Fernão Pires",
    "Airén",
    "Dornfelder",
    "Rivaner",
    "Bobal",
    "Cortese",
    "Colombard",
    "Bonarda",
    "Teroldego",
    "Petite Sirah",
    "Graciano",
    "Primitivo",
    "Müller-Thurgau",
    "Welschriesling",
    "Trincadeira",
    "Muscat",
    "Ruby Cabernet",
    "Marselan",
    "Touriga Franca",
    "Agiorgitiko",
    "Roussanne",
    "Sauvignon Gris",
    "Alfrocheiro",
    "Viosinho",
    "Moscatel",
    "Viura",
    "Ugni Blanc",
    "Silvaner",
    "Tinta Miúda",
    "Lambrusco",
    "Nero di Troia",
    "Roupeiro",
    "Malvasia Nera",
    "Poulsard",
    "Nosiola",
    "Traminer",
    "Azal",
    "Loureiro",
    "Trajadura",
    "Furmint",
    "Romeiko",
    "Neuburger",
    "Bouvier",
    "Glera",
    "Sercial",
    "Assyrtiko",
    "Scheurebe",
    "Sárga Muskotály",
    "Pedro Ximénez",
    "Weissburgunder",
    "Grechetto",
    "Tinta Amarela",
    "Spätburgunder",
    "Vidal",
    "Gouveio",
    "Rabigato",
    "Petit Courbu",
    "Rieslaner",
    "Inzolia",
    "Blaufränkisch",
    "Huxelrebe",
    "Kékfrankos",
    "Kadarka",
    "Trousseau",
    "Saperavi",
    "Blauburger",
    "Dolcetto",
    "Canaiolo",
    "Nerello Mascalese",
    "Nerello Cappuccio",
    "Xynomavro",
    "Refosco",
    "Trollinger",
    "Mazuelo",
    "Bical",
    "Gamay",
    "Gaglioppo",
    "Manto Negro",
    "Callet",
    "Counoise",
    "Baga",
    "Brachetto",
    "Portugieser",
    "Lagrein",
    "Frappato",
    "Alicante",
    "Jaen",
    "Ciliegiolo",
    "Rufete",
    "Vernatsch",
    "País",
    "Kalecik Karasi",
    "Raboso",
    "Limnio",
    "Marzemino",
    "Mataro",
    "Aglianico",
    "Plavac Mali",
    "Croatina",
    "Vespolina",
    "Freisa",
    "Durif",
    "Tinto Fino",
    "Sagrantino",
    "Mandilaria",
    "Moreto",
    "Garnacha Blanca",
    "Bourboulenc",
    "Muscardin",
    "Tinta Pinheira",
    "Rubired",
    "Magliocco",
    "Cesanese",
    "Öküzgözü",
    "Mavrud",
    "Melnik",
    "Schioppettino",
    "Pinot Nero",
    "Cabernet Dorsa",
    "Abouriou",
    "Sousão",
    "Pedral",
    "Schiava",
    "Clairette",
    "Rubin",
    "Feteasca Neagra",
    "Monica",
    "Groppello",
    "Aramon",
    "Blauer Wildbacher",
    "Sciaccarello",
    "Nielluccio",
    "Vermentino",
    "Rolle",
    "Tibouren",
    "Piedirosso",
    "Blauburgunder",
    "Espadeiro",
    "Grolleau",
    "Parellada",
    "Mondeuse",
    "Trebbiano di Lugana",
    "Lemberger",
    "Negrette",
    "Piquepoul",
    "Prugnolo Gentile",
    "Auxerrois",
    "Mauzac",
    "Aligoté",
    "Meunier",
    "Maria Gomes",
    "Muskateller",
    "Reichensteiner",
    "Malagousia",
    "Cerceal",
    "Rkatsiteli",
    "Chinebuli",
    "Moscato Bianco di Canelli",
    "Verduzzo",
    "Moschofilero",
    "Merseguera",
    "Seyval Blanc",
    "Erbaluce",
    "Folle Blanche",
    "Friulano",
    "Greco",
    "Emir",
    "Treixadura",
    "Godello",
    "Misket",
    "Avesso",
    "Pedernã",
    "Feteasca Regala",
    "Narince",
    "Kerner",
    "Bacchus",
    "Rebula",
    "Olaszrizling",
    "Arrufiac",
    "Roter Veltliner",
    "Savatiano",
    "Kéknyelü",
    "Melon de Bourgogne",
    "Favorita",
    "Romorantin",
    "Chasselas",
    "Merwah",
    "Timorasso",
    "Bombino Bianco",
    "Chiavennasca",
    "Juhfark",
    "Alvarinho",
    "Kangun",
    "Irsai Olivér",
    "Ezerjó",
    "Xynisteri",
    "Koshu",
    "Mission",
    "Prieto Picudo",
    "Cabernet Gernischt",
    "Bastardo",
    "Vranac",
    "Prokupac",
    "Cococciola",
    "Pansa Blanca",
    "Bastard Negre",
    "Verdello",
    "Drupeggio",
    "Malvazija Istarska",
    "Mtsvane",
    "Grauburgunder",
    "Moscatel de Grano Menudo",
    "Albillo",
    "Encruzado",
    "Ehrenfelser",
    "Barcelo",
    "Zierfandler",
    "Rotgipfler",
    "Ortega",
    "Albana",
    "Elbling",
    "Vespaiola",
    "Jacquère",
    "Vernaccia",
    "Segalin",
    "Perle",
    "Smederevka",
    "Chancellor",
    "Len de l'El",
    "Seibel",
    "Acikara",
    "Spourtiko",
    "Charbono",
    "Ormeasco",
    "Lexia",
    "Fié Gris",
    "Sultana",
    "Ottavianello",
    "Listán Blanco",
    "Petite Arvine",
    "Flora",
    "Listrão",
    "Phoenix",
    "Spanna",
    "Aleatico",
    "Szürkebarát",
    "Pamid",
    "Picolit",
    "Talia",
    "Papazkarasi",
    "Lledoner Pelut",
    "Pigato",
    "Frühroter Veltliner",
    "St Laurent",
    "Tamâioasa Româneasca",
    "Concord",
    "Parraleta",
    "Magaratch Ruby",
    "Pinot Beurot",
    "Süssschwarz",
    "Tamyanka",
    "Galego Dourado",
    "Ten Göynek",
    "Aragonês",
    "Cot",
    "Pelaverga",
    "Malvasía Aromática",
    "Taminga",
    "Terret Bourret",
    "Couderc Noir",
    "Periquita",
    "Baco Blanc",
    "Malvasia Cândida",
    "Areni Noir",
    "Terret Gris",
    "Mammolo",
    "Baiyu",
    "Malvasia Manresana",
    "Tarrango",
    "Gewurztraminer",
    "Aspiran",
    "Criolla Chica",
    "Plantscher",
    "Babeasca Neagra",
    "Tokay d'Alsace",
    "Crljenak Kaštelanski",
    "Manseng Noir",
    "Baroque",
    "Malvoisie",
    "Teran",
    "Prosecco",
    "Torbato",
    "Babic",
    "Biancu",
    "Goldberger",
    "Baco Noir",
    "De Chaunac",
    "Pignolo",
    "Maratheftiko",
    "Marmajuelo",
    "Rachuli Mtsvane",
    "Gordo",
    "Delaware",
    "Pineau d'Aunis",
    "Maréchal Foch",
    "Boal",
    "Ranina",
    "Gouais Blanc",
    "Barbarossa",
    "Pinenc",
    "Räuschling",
    "Domina",
    "Meksassi",
    "Borrado das Moscas",
    "Tinta Cão",
    "Grasa",
    "Tinta Carvalha",
    "Regner",
    "Graševina",
    "Tresallier",
    "Dunkelfelder",
    "Mavro",
    "Menu Pineau",
    "Tsulukidze Tetra",
    "Berligou",
    "Mavrodaphne",
    "Carignan Blanc",
    "Tinta Negra",
    "Rhine Riesling",
    "Dzelshavi",
    "Black Muscat",
    "Piñuelo",
    "Rhoditis",
    "Vasilissa",
    "Minutolo",
    "Etraire de l'Aduï",
    "Portan",
    "Cayetana Blanca",
    "Tintilia",
    "Evmolpia",
    "Melnik 55",
    "Blauer Arbst",
    "Molette",
    "Cayuga White",
    "Fer Servadou",
    "Mencía",
    "Blauer Frühburgunder",
    "Mondeuse Blanche",
    "Riesling Italico",
    "Grolleau Gris",
    "Blauer Spätburgunder",
    "Pressac",
    "Morava",
    "Cereza",
    "Fogoneu",
    "Morillon",
    "Chardonel",
    "Tribidrag",
    "Rizling",
    "Gros Plant",
    "Franconia",
    "Morio-Muskat",
    "Fränkischer Burgunder",
    "Modra Frankinja",
    "Chasan",
    "Robola",
    "Gutedel",
    "Frankovka",
    "Modri Pinot",
    "Gutenborner",
    "Ull de Llebre",
    "Rollo",
    "Hanepoot",
    "Mollard",
    "Braquet",
    "Ramisco",
    "Chevrier",
    "Uva Rara",
    "Hárslevelu",
    "Villard Blanc",
    "Frühburgunder",
    "Breton",
    "Vaccarèse",
    "Heida",
    "Refosco di Faedis",
    "Brocol",
    "Mtsvivani Kakhuri",
    "Valdiguié",
    "Himbertscha",
    "Brunello",
    "Completer",
    "Vavrinecke",
    "Humagne",
    "Gamay del Trasimeno",
    "Rondo",
    "Burgund Mare",
    "Voskeat",
    "Gamé",
    "Morellino",
    "Rossese",
    "Criolla Grande",
    "Roussette",
    "Hüyük  Ak Üzümü",
    "Gamza",
    "Rouchet",
    "Crouchen",
    "Ruländer",
    "Villard Noir",
    "Gänsfüsser",
    "Weisser Riesling",
    "Moristel",
    "Royalty",
    "Debina",
    "Muskotály",
    "Sacy",
    "Morrastel",
    "Dimyat",
    "Sämling 88",
    "Italian Riesling",
    "Garrut",
    "Xarello",
    "Moshomavro",
    "Dinka",
    "Mourisco Tinto",
    "Niagara",
    "Cabernet Severny",
    "Jaén Blanca",
    "Grand Noir de la Calmette",
    "Zalema",
    "Ruen",
    "Johannisberg",
    "White",
    "Zeleni Silvanec",
    "Müllerebe",
    "Nuragus",
    "Sauvignon Vert",
    "Grignolino",
    "Agrippiotis",
    "Emerald Riesling",
    "Muscat Hamburg",
    "Salvador",
    "Ondenc",
    "Karlovo Misket",
    "Alarije",
    "Zilavka",
    "Samsó",
    "Optima",
    "Carcajolo Nero",
    "Harriague",
    "Albalonga",
    "Samtrot",
    "Negramoll",
    "Orémus",
    "Helfensteiner",
    "Schönburger",
    "Esgana",
    "Carignan Noir",
    "Heroldrebe",
    "Scuppernong",
    "Királeányka",
    "Palomino Fino",
    "Isabella",
    "Semillon",
    "Brachetto d'Acqui",
    "Kizil Üzüm",
    "Faber",
    "Carnelian",
    "Klevner",
    "Pardina",
    "João de Santarém",
    "Altesse",
    "Nero d'Avola",
    "Schwarzblauer Riesling",
    "Catawba",
    "Jurançon Noir",
    "Siegerrebe",
    "Laški",
    "Schwarzriesling",
    "Fendant",
    "Cencibel",
    "Amigne",
    "Laški Rizling",
    "Schwarzurban",
    "Centurian",
    "Ansonica",
    "Šipon",
    "Moscato Bianco",
    "Leányka",
    "Norton",
    "Feteasca Alba",
    "Karmrahyut",
    "Chambourcin",
    "Acıkara",
    "Băbească Neagră",
    "Babić",
    "Fetească Neagră",
    "Kalecik Karası",
    "Fetească Alba",
    "Fetească Regală",
    "Grasă",
    "Hárslevelű",
    "Kızıl Üzüm",
    "Tămâioasă Românească",
]

subregion_pool = [
    "Hunter’s Valley",
    "Kamptal",
    "Toro",
    "Soave",
    "Yarra Valley",
    "Vinho Verde",
    "Elgin",
    "Sauternes",
    "Kremstal",
    "Chianti",
    "Ribera del Duero",
    "Riais Baixas",
    "Geelong",
    "Walker Bay",
    "Barossa Valley",
    "Weinvertel",
    "Brunello di Montalcino",
    "Bierzo",
    "Wairarapa",
    "Macedon Ranges",
    "Swartland",
    "Languedoc",
    "Eden Valley",
    "Carnumtum",
    "Vino Nobile di Monteulciano",
    "Howkes Bay",
    "Napa County",
    "Napa Valley",
    "Rutherglen",
    "Paarl",
    "Jeres",
    "Roussillon",
    "Adelaide Hills",
    "Super Tuscan",
    "Cava",
    "Sonoma Count",
    "Stellenbosch",
    "Malaga",
    "Northern Rhône",
    "McLaren Vale",
    "Graves",
    "Peñedes",
    "Dão",
    "Mendocino Country",
    "Margaret River",
    "Constantia",
    "Southern Rhône",
    "Coonawarra",
    "Médoc",
    "Amarone della Valpolicella",
    "Priorat",
    "Bairrada",
    "Barolo",
    "Rueda",
    "Libournais",
    "Valpolicella",
    "Wachau",
    "Barbaresco",
    "Argentina",
    "Mornington Peninsula",
    "Barossa",
    "Clare Valley",
    "Serra Gaucha",
    "niagara peninsula",
    "Okanagan Valley",
    "Valle Central",
    "Chablis",
    "Côte de Nuits",
    "Côte de Beaune",
    "Côte Chalonnaise",
    "Maconnais",
    "Vino Nobile di Montepulciano",
    "Hawkes Bay",
    "Nelson",
    "Marlborough",
    "Central Otago",
    "Beira Interior",
    "Coastal Region",
    "Breede River Valley",
    "Cape South Coast",
    "Klein Karoo",
    "Olifant River",
    "Sonoma County",
    "Mendocino County",
]

region_pool = [
    "Sardinia",
    "Rheinhessen",
    "Valencia",
    "Israel",
    "Provence",
    "Ontario",
    "Minho",
    "Morocco",
    "Argentina",
    "Castila la Mancha",
    "Toscana",
    "Pflaz",
    "Valais",
    "Abbruzo",
    "Corse",
    "Nova Scotia",
    "Tejo",
    "North Island",
    "New South Wales",
    "Catalunya",
    "Trentino Alto Adige",
    "Nahe",
    "Basilicata",
    "Languedoc Roussillon",
    "British Columbia",
    "South Island",
    "Queenland",
    "Galicia",
    "Umbria",
    "Franken",
    "Turkey",
    "Calabria",
    "Loire Valley",
    "Azores",
    "Nelson",
    "Tasmania",
    "Valle d'Aosta",
    "Balearic Islands",
    "Baden",
    "Ukraine",
    "Campania",
    "Rhône Valley",
    "Chile",
    "Romania",
    "Marlborough",
    "Victoria",
    "Sicily",
    "Canary Islands",
    "United Kingdom",
    "Emilia Romagna",
    "Savoie",
    "China",
    "Russian Federation",
    "Central Otago",
    "South Australia",
    "Navarra",
    "Macedonia",
    "Uruguay",
    "Friuli Venezia Giulia",
    "Jura",
    "Croatia",
    "Slovenia",
    "Western Australia",
    "Rioja",
    "Peloponnese",
    "Veneto",
    "California",
    "Lazio",
    "Cyprus",
    "Costal Region",
    "Alentejo",
    "Lower Austria",
    "Extremandura",
    "Santorini",
    "Japan",
    "Washington",
    "Liguria",
    "Alsace",
    "South West",
    "Cape South Coast",
    "Beiras",
    "Vien",
    "Murcia",
    "Oregon",
    "Lebanon",
    "Beaujolais",
    "Lombardia",
    "Burgenland",
    "Levante",
    "Tokaj",
    "New York",
    "Mexico",
    "Bordeaux",
    "Douro",
    "Marche",
    "Andalucia",
    "Stryia",
    "Aragon",
    "Burgundy",
    "Moldova, Republic of",
    "Lisboa",
    "Piemonte",
    "Castilla y Leon",
    "Brazil",
    "India",
    "Champagne",
    "Madeira",
    "Puglia",
    "Bulgaria",
    "Georgia",
    "Mosel Saar Rüwer",
    "Ahr",
    "Rheingau",
    "Terras do Dao",
    "Beira Atlantico",
    "Terras de Cister",
    "Terras da Beira",
    "Western Cape",
]
